---
name: 功能请求
about: 为这个项目提出改进意见。
title: ''
labels: enhancement
assignees: ''

---

**你的功能请求是否与某个问题有关？**
请尽量清晰精准地描述你遇到的问题。例如：我家运营商限制 UDP 协议速度，导致 Hysteria 很慢，希望增加 FakeTCP 支持。

**描述你希望的解决方案**
请尽量清晰精准地描述你希望的解决方案。

**有没有其他替代方案**
请尽量清晰精准地描述你认为可能的替代方案。

**额外信息**
其他你认为有助于开发者了解你需求的信息。
